@@ -118,7 +118,6 @@
 #undef HAVE_LIBTIFF
 #undef HAVE_LIBZ
 #undef HAVE_LIBPNG
-#undef GNOME_ENABLE_DEBUG
 #undef HAVE_GMP2_INCLUDE_DIR
 #undef HAVE_GUILE
 
@@ -141,3 +140,15 @@
 
 #undef HAVE_XAUTH
 
+/* Define if your have the I4B package. */
+#undef HAVE_I4B
+#undef HAVE_I4B_ACCT
+
+/* Define to enable debugging. */
+#undef LIBGTOP_ENABLE_DEBUG
+#undef LIBGTOP_FATAL_WARNINGS
+
+/* Same as LINUX_VERSION_CODE either from <linux/version.h> or from
+ * the running kernel (if we don't have configured kernel sources).
+ */
+#undef GLIBTOP_LINUX_VERSION_CODE
