@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: procuid.h,v 1.9 1998/10/11 18:14:11 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -81,25 +81,6 @@ extern void glibtop_init_proc_uid_s __P((glibtop *));
 extern void glibtop_get_proc_uid_s __P((glibtop *, glibtop_proc_uid *, pid_t));
 #endif
 
-#ifdef GLIBTOP_GUILE
-
-/* You need to link with -lgtop_guile to get this stuff here. */
-
-extern SCM glibtop_guile_get_proc_uid __P((SCM));
-
-#endif
-
-#ifdef GLIBTOP_GUILE_NAMES
-
-/* You need to link with -lgtop_guile_names to get this stuff here. */
-
-extern SCM glibtop_guile_names_proc_uid __P((void));
-extern SCM glibtop_guile_types_proc_uid __P((void));
-extern SCM glibtop_guile_labels_proc_uid __P((void));
-extern SCM glibtop_guile_descriptions_proc_uid __P((void));
-
-#endif
-
 #ifdef GLIBTOP_NAMES
 
 /* You need to link with -lgtop_names to get this stuff here. */
