@@ -1,4 +1,4 @@
-/* $Id: version.c,v 1.2 1998/08/25 08:20:04 martin Exp $ */
+/* $Id: version.c,v 1.3 1998/10/03 03:01:20 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -38,7 +38,9 @@ glibtop_send_version (glibtop *server, int fd)
 	
 	size = strlen (buffer) + 1;
 
+#ifdef DEBUG
 	fprintf (stderr, "SERVER ID: |%s|\n", buffer);
+#endif
 
 	if (fd == 0) {
 		if (write (1, (const void *) &size, sizeof (size)) < 0)
