@@ -1,4 +1,4 @@
-/* $Id: close.c,v 1.2 1998/08/07 15:11:50 martin Exp $ */
+/* $Id: close.c,v 1.4 1998/10/06 09:04:18 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -19,10 +19,11 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
+#include <glibtop.h>
 #include <glibtop/close.h>
 
 /* Closes pipe to gtop server. */
 
 void
-glibtop_close_l (glibtop *server)
+glibtop_close_p (glibtop *server)
 { }
