@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.6 1998/08/24 19:55:30 martin Exp $ */
+/* $Id: procsegment.c,v 1.8 1998/10/06 09:04:22 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -46,9 +46,6 @@ glibtop_get_proc_segment_p (glibtop *server,
 			    glibtop_proc_segment *buf,
 			    pid_t pid)
 {
-	struct kinfo_proc *pinfo;
-	int *count;
-
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_segment));
