@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.6 1998/08/24 19:55:31 martin Exp $ */
+/* $Id: procsignal.c,v 1.9 1998/11/11 15:58:19 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -51,34 +51,35 @@ glibtop_get_proc_signal_p (glibtop *server,
 	
 	memset (buf, 0, sizeof (glibtop_proc_signal));
 
-	glibtop_suid_enter (server);
-
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
 	/* Get the process information */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count != 1))
-		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
-
-	glibtop_suid_leave (server);
+	if ((pinfo == NULL) || (count != 1)) {
+		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
+		return;
+	}
 
 	/* signal: mask of pending signals.
 	 *         pinfo [0].kp_proc.p_siglist
 	 */
-	buf->signal = pinfo [0].kp_proc.p_siglist;
+	buf->signal [0] = pinfo [0].kp_proc.p_siglist;
 
 	/* blocked: mask of blocked signals.
 	 *          pinfo [0].kp_proc.p_sigmask
 	 */
-	buf->blocked = pinfo [0].kp_proc.p_sigmask;
+	buf->blocked [0] = pinfo [0].kp_proc.p_sigmask;
 	
 	/* sigignore: mask of ignored signals.
 	 *            pinfo [0].kp_proc.p_sigignore
 	*/
-	buf->sigignore = pinfo [0].kp_proc.p_sigignore;
+	buf->sigignore [0] = pinfo [0].kp_proc.p_sigignore;
 	
 	/* sigcatch: mask of caught signals.
 	 *           pinfo [0].kp_proc.p_sigcatch
 	*/
-	buf->sigcatch = pinfo [0].kp_proc.p_sigcatch;
+	buf->sigcatch [0] = pinfo [0].kp_proc.p_sigcatch;
 
 	buf->flags = _glibtop_sysdeps_proc_signal;
 }
