@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.5 1998/08/24 19:55:37 martin Exp $ */
+/* $Id: swap.c,v 1.9 1998/12/06 17:54:17 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -27,15 +27,17 @@
 
 #include <glibtop_suid.h>
 
-#include <sys/conf.h>
-#include <sys/rlist.h>
-#include <sys/vmmeter.h>
-
 static const unsigned long _glibtop_sysdeps_swap =
 (1 << GLIBTOP_SWAP_TOTAL) + (1 << GLIBTOP_SWAP_USED) +
 (1 << GLIBTOP_SWAP_FREE) + (1 << GLIBTOP_SWAP_PAGEIN) +
 (1 << GLIBTOP_SWAP_PAGEOUT);
 
+#ifdef __FreeBSD__
+
+#include <sys/conf.h>
+#include <sys/rlist.h>
+#include <sys/vmmeter.h>
+
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
 #define VM_SWAPLIST	0
@@ -51,15 +53,36 @@ static struct nlist nlst [] = {
 	{ 0 }
 };
 
+#elif (defined __NetBSD__)
+
+#include <vm/vm_swap.h>
+
+#endif
+
+/* nlist structure for kernel access */
+static struct nlist nlst2 [] = {
+	{ "_cnt" },
+	{ 0 }
+};
+
 /* Init function. */
 
 void
 glibtop_init_swap_p (glibtop *server)
 {
-	server->sysdeps.swap = _glibtop_sysdeps_swap;
+#ifdef __FreeBSD__
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (swap)");
+		return;
+	}
+#endif
 
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
-		glibtop_error_io_r (server, "kvm_nlist");
+	if (kvm_nlist (server->machine.kd, nlst2) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (swap)");
+		return;
+	}
+
+	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
 
 /* Provides information about swap usage. */
@@ -72,9 +95,10 @@ glibtop_init_swap_p (glibtop *server)
 void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
+#ifdef __FreeBSD__
 	char *header;
-	int hlen, nswap, nswdev, dmmax;
-	int i, div, avail, nfree, npfree, used;
+	int hlen, nswdev, dmmax;
+	int div, nfree, npfree;
 	struct swdevt *sw;
 	long blocksize, *perdev;
 	struct rlist head;
@@ -82,6 +106,12 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	struct rlist *swapptr;
 	size_t sw_size;
 	u_long ptr;
+#elif (defined __NetBSD__)
+	struct swapent *swaplist;
+#endif
+
+	int nswap, i;
+	int avail = 0, inuse = 0;
 
 	/* To get `pagein' and `pageout'. */
 	struct vmmeter vmm;
@@ -92,60 +122,89 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	
 	memset (buf, 0, sizeof (glibtop_swap));
 
+	if (server->sysdeps.swap == 0)
+		return;
+
 	/* This is used to get the `pagein' and `pageout' members. */
 	
-	if (kvm_read (server->machine.kd, nlst[0].n_value,
-		      &vmm, sizeof (vmm)) != sizeof (vmm))
-		glibtop_error_io_r (server, "kvm_read (cnt)");
-	
+	if (kvm_read (server->machine.kd, nlst2[0].n_value,
+		      &vmm, sizeof (vmm)) != sizeof (vmm)) {
+		glibtop_warn_io_r (server, "kvm_read (cnt)");
+		return;
+	}
+
         if (swappgsin < 0) {
 		buf->pagein = 0;
 		buf->pageout = 0;
 	} else {
+#ifdef __FreeBSD__
 		buf->pagein = vmm.v_swappgsin - swappgsin;
 		buf->pageout = vmm.v_swappgsout - swappgsout;
+#else
+		buf->pagein = vmm.v_swpin - swappgsin;
+		buf->pageout = vmm.v_swpout - swappgsout;
+#endif
 	}
 
+#ifdef __FreeBSD__
         swappgsin = vmm.v_swappgsin;
 	swappgsout = vmm.v_swappgsout;
+#else
+	swappgsin = vmm.v_swpin;
+	swappgsout = vmm.v_swpout;
+#endif
+
+#ifdef __FreeBSD__
 
 	/* Size of largest swap device. */
 
 	if (kvm_read (server->machine.kd, nlst[VM_NSWAP].n_value,
-		      &nswap, sizeof (nswap)) != sizeof (nswap))
-		glibtop_error_io_r (server, "kvm_read (nswap)");
+		      &nswap, sizeof (nswap)) != sizeof (nswap)) {
+		glibtop_warn_io_r (server, "kvm_read (nswap)");
+		return;
+	}
 
 	/* Number of swap devices. */
 
 	if (kvm_read (server->machine.kd, nlst[VM_NSWDEV].n_value,
-		      &nswdev, sizeof (nswdev)) != sizeof (nswdev))
-		glibtop_error_io_r (server, "kvm_read (nswdev)");
+		      &nswdev, sizeof (nswdev)) != sizeof (nswdev)) {
+		glibtop_warn_io_r (server, "kvm_read (nswdev)");
+		return;
+	}
 
 	/* Maximum size of a swap block. */
 
 	if (kvm_read (server->machine.kd, nlst[VM_DMMAX].n_value,
-		      &dmmax, sizeof (dmmax)) != sizeof (dmmax))
-		glibtop_error_io_r (server, "kvm_read (dmmax)");
+		      &dmmax, sizeof (dmmax)) != sizeof (dmmax)) {
+		glibtop_warn_io_r (server, "kvm_read (dmmax)");
+		return;
+	}
 
 	/* List of free swap areas. */
 
 	if (kvm_read (server->machine.kd, nlst[VM_SWAPLIST].n_value,
-		      &swaplist, sizeof (swaplist)) != sizeof (swaplist))
-		glibtop_error_io_r (server, "kvm_read (swaplist)");
+		      &swaplist, sizeof (swaplist)) != sizeof (swaplist)) {
+		glibtop_warn_io_r (server, "kvm_read (swaplist)");
+		return;
+	}
 
 	/* Kernel offset of list of swap devices and sizes. */
 
 	if (kvm_read (server->machine.kd, nlst[VM_SWDEVT].n_value,
-		      &ptr, sizeof (ptr)) != sizeof (ptr))
-		glibtop_error_io_r (server, "kvm_read (swaplist)");
+		      &ptr, sizeof (ptr)) != sizeof (ptr)) {
+		glibtop_warn_io_r (server, "kvm_read (swaplist)");
+		return;
+	}
 
 	/* List of swap devices and sizes. */
 
 	sw_size = nswdev * sizeof (*sw);
 	sw = glibtop_malloc_r (server, sw_size);
 
-	if (kvm_read (server->machine.kd, ptr, sw, sw_size) != sw_size)
-		glibtop_error_io_r (server, "kvm_read (*swdevt)");
+	if (kvm_read (server->machine.kd, ptr, sw, sw_size) != (ssize_t)sw_size) {
+		glibtop_warn_io_r (server, "kvm_read (*swdevt)");
+		return;
+	}
 
 	perdev = glibtop_malloc (nswdev * sizeof (*perdev));
 
@@ -160,8 +219,10 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		int	top, bottom, next_block;
 
 		if (kvm_read (server->machine.kd, (int) swapptr, &head,
-			      sizeof (struct rlist)) != sizeof (struct rlist))
-			glibtop_error_io_r (server, "kvm_read (swapptr)");
+			      sizeof (struct rlist)) != sizeof (struct rlist)) {
+			glibtop_warn_io_r (server, "kvm_read (swapptr)");
+			return;
+		}
 
 		top = head.rl_end;
 		bottom = head.rl_start;
@@ -211,7 +272,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		 */
 		xsize = sw[i].sw_nblks - dmmax;
 		xfree = perdev[i];
-		used = xsize - xfree;
+		inuse = xsize - xfree;
 		npfree++;
 		avail += xsize;
 	}
@@ -220,14 +281,46 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	 * If only one partition has been set up via swapon(8), we don't
 	 * need to bother with totals.
 	 */
-	used = avail - nfree;
+	inuse = avail - nfree;
 
 	glibtop_free_r (server, sw);
 	glibtop_free_r (server, perdev);
 
-	buf->used = used;
+	buf->flags = _glibtop_sysdeps_swap;
+
+	buf->used = inuse;
 	buf->free = avail;
 
-	buf->total = used + avail;
+	buf->total = inuse + avail;
+
+#elif (defined __NetBSD__)
+
+	nswap = swapctl (SWAP_NSWAP, NULL, 0);
+	if (nswap < 0) {
+		glibtop_warn_io_r (server, "swapctl (SWAP_NSWAP)");
+		return;
+	}
+
+	swaplist = glibtop_calloc_r (server, nswap, sizeof (struct swapent));
+
+	if (swapctl (SWAP_STATS, swaplist, nswap) != nswap) {
+		glibtop_warn_io_r (server, "swapctl (SWAP_STATS)");
+		glibtop_free_r (server, swaplist);
+		return;
+	}
+
+	for (i = 0; i < nswap; i++) {
+		avail += swaplist[i].se_nblks;
+		inuse += swaplist[i].se_inuse;
+	}
+
+	glibtop_free_r (server, swaplist);
+
 	buf->flags = _glibtop_sysdeps_swap;
+
+	buf->used = inuse;
+	buf->free = avail;
+
+	buf->total = inuse + avail;
+#endif
 }
