@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: glibtop_server.h,v 1.6 1998/10/26 10:39:05 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -122,7 +122,10 @@ proc_stat_after_cmd (char *p)
 #define GLIBTOP_SUID_PROC_SIGNAL	0
 #define GLIBTOP_SUID_PROC_KERNEL	0
 #define GLIBTOP_SUID_PROC_SEGMENT	0
+#define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
+#define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_PPP		0
 
 __END_DECLS
 
